==> icon_9.1.orig.tar.gz: icon-9.1.orig/src/rtt/ltoken.h <==

typedef union  {
   struct token *t;
   struct node *n;
   long i;
   } YYSTYPE;
extern YYSTYPE yylval;
# define Identifier 257
# define StrLit 258
# define LStrLit 259
# define FltConst 260
# define DblConst 261
# define LDblConst 262
# define CharConst 263
# define LCharConst 264
# define IntConst 265
# define UIntConst 266
# define LIntConst 267
# define ULIntConst 268
# define Arrow 269
# define Incr 270
# define Decr 271
# define LShft 272
# define RShft 273
# define Leq 274
# define Geq 275
# define Equal 276
# define Neq 277
# define And 278
# define Or 279
# define MultAsgn 280
# define DivAsgn 281
# define ModAsgn 282
# define PlusAsgn 283
# define MinusAsgn 284
# define LShftAsgn 285
# define RShftAsgn 286
# define AndAsgn 287
# define XorAsgn 288
# define OrAsgn 289
# define Sizeof 290
# define Intersect 291
# define OpSym 292
# define Typedef 293
# define Extern 294
# define Static 295
# define Auto 296
# define Register 297
# define Tended 298
# define Char 299
# define Short 300
# define Int 301
# define Long 302
# define Signed 303
# define Unsigned 304
# define Float 305
# define Doubl 306
# define Const 307
# define Volatile 308
# define Void 309
# define TypeDefName 310
# define Struct 311
# define Union 312
# define Enum 313
# define Ellipsis 314
# define Case 315
# define Default 316
# define If 317
# define Else 318
# define Switch 319
# define While 320
# define Do 321
# define For 322
# define Goto 323
# define Continue 324
# define Break 325
# define Return 326
# define Runerr 327
# define Is 328
# define Cnv 329
# define Def 330
# define Exact 331
# define Empty_type 332
# define IconType 333
# define Component 334
# define Variable 335
# define Any_value 336
# define Named_var 337
# define Struct_var 338
# define C_Integer 339
# define Arith_case 340
# define C_Double 341
# define C_String 342
# define Tmp_string 343
# define Tmp_cset 344
# define Body 345
# define End 346
# define Function 347
# define Keyword 348
# define Operator 349
# define Underef 350
# define Declare 351
# define Suspend 352
# define Fail 353
# define Inline 354
# define Abstract 355
# define Store 356
# define Type 357
# define New 358
# define All_fields 359
# define Then 360
# define Type_case 361
# define Of 362
# define Len_case 363
# define Constant 364
# define Errorfail 365
# define IfStmt 366

==> icon_9.4.3.orig.tar.gz: icon-9.4.3/src/rtt/ltoken.h <==

typedef union  {
   struct token *t;
   struct node *n;
   long i;
   } YYSTYPE;
extern YYSTYPE yylval;
# define Identifier 257
# define StrLit 258
# define LStrLit 259
# define FltConst 260
# define DblConst 261
# define LDblConst 262
# define CharConst 263
# define LCharConst 264
# define IntConst 265
# define UIntConst 266
# define LIntConst 267
# define ULIntConst 268
# define Arrow 269
# define Incr 270
# define Decr 271
# define LShft 272
# define RShft 273
# define Leq 274
# define Geq 275
# define TokEqual 276
# define Neq 277
# define And 278
# define Or 279
# define MultAsgn 280
# define DivAsgn 281
# define ModAsgn 282
# define PlusAsgn 283
# define MinusAsgn 284
# define LShftAsgn 285
# define RShftAsgn 286
# define AndAsgn 287
# define XorAsgn 288
# define OrAsgn 289
# define Sizeof 290
# define Intersect 291
# define OpSym 292
# define Typedef 293
# define Extern 294
# define Static 295
# define Auto 296
# define TokRegister 297
# define Tended 298
# define TokChar 299
# define TokShort 300
# define Int 301
# define TokLong 302
# define Signed 303
# define Unsigned 304
# define Float 305
# define Doubl 306
# define Const 307
# define Volatile 308
# define Void 309
# define TypeDefName 310
# define Struct 311
# define Union 312
# define TokEnum 313
# define Ellipsis 314
# define Case 315
# define Default 316
# define If 317
# define Else 318
# define Switch 319
# define While 320
# define Do 321
# define For 322
# define Goto 323
# define Continue 324
# define Break 325
# define Return 326
# define Runerr 327
# define Is 328
# define Cnv 329
# define Def 330
# define Exact 331
# define Empty_type 332
# define IconType 333
# define Component 334
# define Variable 335
# define Any_value 336
# define Named_var 337
# define Struct_var 338
# define C_Integer 339
# define Arith_case 340
# define C_Double 341
# define C_String 342
# define Tmp_string 343
# define Tmp_cset 344
# define Body 345
# define End 346
# define TokFunction 347
# define Keyword 348
# define Operator 349
# define Underef 350
# define Declare 351
# define Suspend 352
# define Fail 353
# define Inline 354
# define Abstract 355
# define Store 356
# define TokType 357
# define New 358
# define All_fields 359
# define Then 360
# define Type_case 361
# define Of 362
# define Len_case 363
# define Constant 364
# define Errorfail 365
# define IfStmt 366
